package ch.epfl.lpd.ids.client;

import ch.epfl.lpd.ids.serialization.IMessage;

/**
 * Specification of a chat client. A chat client should be able to
 * connect/disconnect from the server and send messages to it.
 * @author Sebastien Baehni
 */
public interface IChatClient {
    
    /**
     * Method called when the client wants to connect to a server. We
     * assume that the chat client as a reference to the server it
     * wants to connect to.
     * @param username The username of the client.
     * @return True if the client was able to connect, false
     * otherwise.
     */
    public boolean connect(String username);

    /**
     * Method called when the client wants to disconnect from the
     * server. We assume that the chat client as a reference to the
     * server it wants to be disconnected with.
     * @param username The username of the client.
     * @return True if the client was able to disconnect from the
     * server. False otherwise.
     */
    public boolean disconnect();

    /**
     * Method called when the client wants to send a message to the
     * server. Again, we assume that the client holds a reference to
     * the server.
     * @param message The IMessage to be sent.
     */
    public void sendMessage(IMessage message);    
    
}
